<template>
  <van-popup
    v-model="isShowPopup"
    :close-on-click-overlay="false"
    position="right"
    :style="{ width:'100%',height: '100%' }"
    @open="open"
    @closed="closed"
  >

    <div class="details-container">
      <!--  头部  -->
      <van-sticky>
        <van-nav-bar
          title="详情"
          left-arrow
          @click-left="_ => isShowPopup = false"
        />
      </van-sticky>

      <van-form
        label-width="auto"
      >
        <van-collapse v-model="activeNames">
          <van-collapse-item
            title="安全培训方案信息"
            name="1"
            icon="more-o"
          >
            <van-field
              label="培训项目"
              input-align="right">
              <template #input>
                {{
                  dictionaryEscape(trainingProjectData, formData.trainingProjectId, {valueKey: 'id'}) || '-'
                }}
              </template>
            </van-field>
            <van-field
              label="方案名称"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.planName"
              readonly
            />
            <van-field
              label="参与单位"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.participantCompany"
              readonly
            />
            <van-field
              label="培训类型"
              input-align="right">
              <template #input>
                {{ dictionaryEscape(trainingType2Opt, formData.trainingType2) || '-' }}
              </template>
            </van-field>
            <van-field
              label="培训对象"
              input-align="right">
              <template #input>
                {{ dictionaryEscape(pxdxOpt, formData.pxdx) || '-' }}
              </template>
            </van-field>
            <van-field
              label="工作目的描述"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.trainingPurpost"
              readonly
            />
            <van-field
              label="培训周期"
              input-align="right">
              <template #input>
                {{ dictionaryEscape(trainingCycleOpt, formData.trainingCycle) || '-' }}
              </template>
            </van-field>
            <van-field
              label="培训频次"
              input-align="right">
              <template #input>
                {{ formData.pxpl ? formData.pxpl + '次' : '-' }}
              </template>
            </van-field>
            <van-field
              label="活动地点"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.location"
              readonly
            />
            <van-field
              label="活动开始时间"
              input-align="right">
              <template #input>
                {{ formData.trainingStartDate || '-' }}
              </template>
            </van-field>
            <van-field
              label="活动结束时间"
              input-align="right">
              <template #input>
                {{ formData.trainingEndDate || '-' }}
              </template>
            </van-field>
            <van-field
              label="参加人员描述"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.participant"
              readonly
            />
            <van-field
              label="活动主办方"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.sponsor"
              readonly
            />
            <van-field
              label="内容描述"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.content"
              readonly
            />
            <van-field
              label="注意事项描述"
              input-align="right"
              rows="1"
              autosize
              placeholder="-"
              type="textarea"
              v-model="formData.notes"
              readonly
            />
            <van-field
              label="附件"
              label-width="100px"
              name="caseFileArr"
              input-align="right"
            >
              <template #input>
                <van-uploader
                  v-model="formData.fileListArr"
                  @click-preview="clickPreview"
                />
              </template>
            </van-field>
          </van-collapse-item>
        </van-collapse>
      </van-form>

      <van-overlay :show="loading">
        <van-loading color="#1989fa" size="24px">详情加载中...</van-loading>
      </van-overlay>
    </div>

  </van-popup>
</template>

<script>
import moment from 'moment'
import {dictionaryEscape} from '@/utils/dictionary'
import CmgtSaftyTrainingPlanApi from '@/views/Manage/saftyTraining/api/CmgtSaftyTrainingPlanApi'
import CmgtSaftyTrainingProjectApi from '@/views/Manage/saftyTraining/api/CmgtSaftyTrainingProjectApi'


export default {
  name: 'DetailsPopup',
  props: {
    // 是否展示弹层
    isShow: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default: () => ({}),
      type: Object
    },
    trainingType2Opt: {
      default: () => ([]),
      type: Array
    },
    pxdxOpt: {
      default: () => ([]),
      type: Array
    },
    trainingCycleOpt: {
      default: () => ([]),
      type: Array
    }
  },
  data() {
    return {
      formData: {},
      loading: false,
      activeNames: [], // 手风琴展开数组
      trainingProjectData: [], // 培训项目配置数组
      saftyDangeData: [] // 参与单位配置数组
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.isShow
      },
      set(val) {
        this.$emit('update:isShow', val)
      }
    },
    previewUrl() {
      return window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
    }
  },
  created() {
  },
  methods: {
    dictionaryEscape,
    moment,

    clickPreview(e) {
      if (!e.isImage) {
        window.location.href = e.url
      }
    },

    // 弹层打开
    open() {
      if (this.rowInfo.id) {
        this.loading = true
        Promise.all([this.saftyDangerUnit(), this.loadCmgtSaftyTraining()]).then(_ => {
          CmgtSaftyTrainingPlanApi.cmgtSaftyTrainPlanId(this.rowInfo.id, res => {
            const {fileList = [], participantCompany = '', ...formData} = res
            this.formData = {
              ...formData,
              fileList: fileList,
              participantCompany: participantCompany.split(',').flatMap(id => {
                const label = this.saftyDangeData.find(i => i.id === id)?.unitName || ''
                return label ? label : []
              }).join(','),
              fileListArr: fileList ? fileList.map(item => ({
                url: this.previewUrl + item.id,
                file: new File([], item.fileName + '.' + item.extensionName, {}),
                isImage: /(jpg|jpeg|png|gif|bmp)$/i.test(item.extensionName)
              })) : []
            }
            this.activeNames = ['1']
            this.loading = false
          })
        })
      } else {
        this.isShowPopup = false
      }
    },

    // 获取培训项目配置数组
    loadCmgtSaftyTraining() {
      return new Promise(resolve => {
        CmgtSaftyTrainingProjectApi.loadCmgtSaftyTrainingProject(
          {
            groupTree: {},
            pageBean: {
              page: 1,
              pageSize: 10,
              showTotal: true
            }
          },
          res => {
            this.trainingProjectData = res.rows
            resolve(this.trainingProjectData)
          }
        )
      })

    },

    // 获取参与单位配置数组
    saftyDangerUnit() {
      return new Promise(resolve => {
        CmgtSaftyTrainingPlanApi.cmgtSaftyDangerUnit(
          {
            groupRelation: 'AND',
            groupTree: {},
            pageBean: {
              page: 0,
              pageSize: -1,
              showTotal: true
            }
          },
          res => {
            this.saftyDangeData = res.rows
            resolve(this.saftyDangeData)
          }
        )
      })
    },

    // 弹层关闭
    closed() {
      // 重置组件内的数据
      Object.assign(this.$data, this.$options.data.call(this))
    }
  }
}
</script>

<style lang="scss" scoped>
.details-container {
  width: 100%;
  height: 100%;
  background: #fff;
  display: flex;
  flex-direction: column;

  ::v-deep .van-form {
    flex: 1;
    overflow: auto;
    padding-bottom: 40PX;

    .van-uploader__wrapper {
      .van-uploader__upload {
        display: none;
      }

      .van-uploader__preview-delete {
        display: none;
      }
    }
  }


  ::v-deep .van-action-sheet__close {
    display: none;
  }

  ::v-deep .van-collapse-item__content {
    padding: 0 0 0 20PX;
    margin-bottom: 5PX;

    .multiple-box {
      display: flex;
      flex-direction: column;
      row-gap: 10PX;

      .multiple-box-item {
        border: 1px solid #c9c9c9;
        margin-right: 10PX;
      }
    }


  }

  ::v-deep .van-overlay {
    display: flex;
    justify-content: center;
    align-items: center;
  }

}
</style>

